---
title: E-mail Service;
layout: page
---

For accessing mail via IMAP, webmail, or for changing the server-side filters, you will need to use the same login credentials, namely your Luon user name and password. As user name use the name of your Luon account without any domain, so `user` and not `user@luon.net` .

We also support virtual mail accounts.  In this case the user name that shlould be used *does* include the domain, so  `virtualuser@yourdomain.tld`.
If you would like to have (more) virtual mail boxes/addresses, just let [our postmaster](mailto:postmaster@luon.net) know!

## Accessing mail

### Retrieving mail

If you have not specified a forwarding e-mail address in `~/.forward`, arriving e-mail will be stored in `~/Mail` of your (UNIX) account.  Under this directory there is a nested tree of directories where `cur`, `new` and `tmp` are special [Maildir format specific](http://cr.yp.to/proto/maildir.html) directories.

The _preferred_ way to access the e-mail, even on the shell host itself, is via IMAP.  Use the following settings:

* **server:** `imap.luon.net`
* **port:** 143 (imap2)
* **security:** (START)TLS

Optionally, IMAP via SSL (using port 993) is also supported but not preferred.

### Sending e-mail

E-mail can be sent using our mail server wherever your are (especially useful for mobile devices).  Use the following settings:

* **server:** `smtp.luon.net`
* **port:** 587 (submission) or 25 (smtp)
* **security:** (START)TLS

The Submission port (587) is preferred as it is usually not blocked by the firewall of your internet provider, while the SMTP port (25) often is.

The same remarks concerning the Luon and virtual e-mail accounts hold as written above.

## Webmail

The Luon Webmail service is available at: [https://webmail.luon.net/](https://webmail.luon.net).
For the login details, see above.

## Spam-filtering

We support server-side spam filtering by default; this is done using [Rspamd](https://rspamd.com) on our mail gateway host.
Note that it requires some initial training before it starts working properly.
Incoming mail is stored in the _Inbox_ (i.e. `~/Mail`) unless Rspamd thinks it is spam (or junk, as it is often called) based on a score. Either, this score is very high (≥ 15) and the mail is plainly rejected on arrival, or the score is just high (≥ 6 and < 15) and it will be stored in the _Junk_ folder (i.e. `~/Mail/Junk`).

Spam training is done by moving spam e-mails to the Junk mail folder (which must be called like this for it to work) and moving ham e-mails from the Junk mail folder to another folder.  For the training to have effect, this *has to be done via IMAP*. Our IMAP server tracks your actions of moving mail in and out the Junk mail folder and trains accordingly.  Moving them from maildir to maildir on the system will have no effect.

## Server-side mail filtering

Server-side filtering is done using [Sieve](http://en.wikipedia.org/wiki/Sieve_%28mail_filtering_language%29).  Some [e-mail clients](http://sieve.info/clients) support configuring the sieve.  The Luon Webmail is such a client, but there is also an [add-on](https://addons.mozilla.org/en-us/thunderbird/addon/sieve/) for Thunderbird.  Evolution unfortunately has no support at all.

Configuring sieve can be done using our Webmail or via the [manage-sieve protocol](http://tools.ietf.org/html/rfc5804).

### ... via webmail

Login on the [Luon Webmail](https://webmail.luon.net/), go to "Personal Settings" and then select the tab "Filters".
On the left side you can add, remove and reorder rules, on the right side you can edit or temporarily disable the rules.
By default there should already be a "Spam Filter" rule, ensure that you keep it and keep it at the top.

### ... via a manage-sieve client

Use the following settings for a manage-sieve client:

* **server:** imap.luon.net
* **port:** 4190 (*N.B.* This used to be 2000 before!)
* **security:** (START)TLS
* **login:** e-mail account user/password

The filters are stored in `~/.sieves` and the active filter is linked from `~/.dovecot.sieve`.  So, it is also possible to edit the filters via shell and an editor.  However, be sure to make no syntax errors ;)

Warning!  When manually editing filters, the default system filter will be overridden, thus losing spam filter support.  There are two solutions:

1. Add the following to your sieve:

       require ["include"];
       
       include :global "spam_filter";

2. Copy the contents of `/etc/dovecot/sieve.default`, as not all clients support the "include" module yet.

If you prefer procmail, exim filter, or to forward your e-mail, you can always create a `~/.procmailrc` or `~/.forward`, thus overriding the system filtering, including sieve.

## Virtual domains

Besides the `luon.net` mail domain, we also host other virtual domains and virtual mail accounts.  Setting up or tearing down virtual domains or accounts has to be done by the [postmaster](mailto:postmaster@luon.net).  

### Managing virtual domains

Once a virtual domain is created, you can manage it by editing the aliases file `/srv/mail/aliases/mydomain.tld`.  An example aliases file:

```
# Aliases for mydomain.tld
abuse: hostmaster
hostmaster: hostmaster@localhost
info: virtualuser
mailer-daemon: postmaster
postmaster: postmaster@localhost
webmaster: virtualuser

someuser: someuser@localhost
```

In the above virtual mail domain, mail to `abuse@mydomain.tld` and `hostmaster@mydomain.tld` is redirected to the hostmaster listed by the system aliases (in `/etc/aliases`).
Mail to `info@mymaildomain.tld` and `webmaster@mydomain.tld` is redirected to the virtual mail account `virtualuser@mydomain.tld` (if it exists).  
Finally, mail to `someuser@mydomain.tld` is redirected to the (UNIX) account `someuser` if it exists and is not an alias in the system aliases.

Note that adding `@localhost` is required to redirect mail to UNIX accounts, possibly via system aliases.  Leaving the domain suffix out signifies that the mail needs to go to a virtual mail account, if not aliased first.